@@ -507,7 +507,7 @@ Masscan::Scanner - Masscan::Scanner - A Perl module which helps in using the mas
 
 =head1 VERSION
 
-version 20200321.223020
+version 20200321.224511
 
 =head1 SYNOPSIS
 
@@ -551,12 +551,12 @@ version 20200321.223020
 
     # Set the full path to masscan binary
     # Default is the module will automatically find the binary full path if it's
-    # withing the users environment variables
+    # withing the users environment path.
     $mas->binary('/usr/bin/masscan');
 
     # Set the name servers to be used for DNS resolution
     # Default is to use a list of public DNS servers
-    $mas->name_servers(['192.168.0.100', '192.168.0.101]);
+    $mas->name_servers(['192.168.0.100', '192.168.0.101']);
 
     # Will initiate the masscan.
     # If the scan is successful returns True otherwise returns False.
